@@ -16,6 +16,7 @@ from onnx2tf.utils.common_functions import (
     post_process_transpose,
     make_tf_partial_model_inputs,
     dummy_tf_inference,
+    transpose_with_flexing_deterrence,
 )
 from typing import Any, Dict, List
 
@@ -98,10 +99,13 @@ def make_node(
     ]
 
     # NHWC -> HCHW
-    transposed_tensor = tf.transpose(
-        a=input_tensor,
-        perm=list(perm) if perm is not None else None,
-    )
+    transposed_tensor = transpose_with_flexing_deterrence(
+            input_tensor=input_tensor,
+            perm=list(perm) if perm is not None else None,
+            output_shape=output_shape,
+            name=graph_node.name,
+            **kwargs,
+        )
     test_data = None
     if not isinstance(input_tensor, np.ndarray):
         if not isinstance(graph_node_input_1, np.ndarray) \
